@@ -114,9 +114,10 @@ class FeatureBase(object):
 
     def set_feature_names(self, names):
         """Set new values for the feature column names, overriding the default values.
-        Number of names provided much match the number of output columns defined for
-        the feature. Only works for features that have more than one output column. Use
-        ``Feature.rename`` to change the column name for single output features.
+        Number of names provided must match the number of output columns defined for
+        the feature, and all provided names should be unique. Only works for features
+        that have more than one output column. Use ``Feature.rename`` to change the column
+        name for single output features.
 
         Args:
             names (list[str]): List of names to use for the output feature columns. Provided
@@ -275,7 +276,7 @@ class FeatureBase(object):
             "arguments": self.get_arguments(),
         }
 
-    def _handle_binary_comparision(self, other, Primitive, PrimitiveScalar):
+    def _handle_binary_comparison(self, other, Primitive, PrimitiveScalar):
         if isinstance(other, FeatureBase):
             return Feature([self, other], primitive=Primitive)
 
@@ -283,7 +284,7 @@ class FeatureBase(object):
 
     def __eq__(self, other):
         """Compares to other by equality"""
-        return self._handle_binary_comparision(
+        return self._handle_binary_comparison(
             other,
             primitives.Equal,
             primitives.EqualScalar,
@@ -291,7 +292,7 @@ class FeatureBase(object):
 
     def __ne__(self, other):
         """Compares to other by non-equality"""
-        return self._handle_binary_comparision(
+        return self._handle_binary_comparison(
             other,
             primitives.NotEqual,
             primitives.NotEqualScalar,
@@ -299,7 +300,7 @@ class FeatureBase(object):
 
     def __gt__(self, other):
         """Compares if greater than other"""
-        return self._handle_binary_comparision(
+        return self._handle_binary_comparison(
             other,
             primitives.GreaterThan,
             primitives.GreaterThanScalar,
@@ -307,7 +308,7 @@ class FeatureBase(object):
 
     def __ge__(self, other):
         """Compares if greater than or equal to other"""
-        return self._handle_binary_comparision(
+        return self._handle_binary_comparison(
             other,
             primitives.GreaterThanEqualTo,
             primitives.GreaterThanEqualToScalar,
@@ -315,7 +316,7 @@ class FeatureBase(object):
 
     def __lt__(self, other):
         """Compares if less than other"""
-        return self._handle_binary_comparision(
+        return self._handle_binary_comparison(
             other,
             primitives.LessThan,
             primitives.LessThanScalar,
@@ -323,7 +324,7 @@ class FeatureBase(object):
 
     def __le__(self, other):
         """Compares if less than or equal to other"""
-        return self._handle_binary_comparision(
+        return self._handle_binary_comparison(
             other,
             primitives.LessThanEqualTo,
             primitives.LessThanEqualToScalar,
@@ -331,7 +332,7 @@ class FeatureBase(object):
 
     def __add__(self, other):
         """Add other"""
-        return self._handle_binary_comparision(
+        return self._handle_binary_comparison(
             other,
             primitives.AddNumeric,
             primitives.AddNumericScalar,
@@ -342,7 +343,7 @@ class FeatureBase(object):
 
     def __sub__(self, other):
         """Subtract other"""
-        return self._handle_binary_comparision(
+        return self._handle_binary_comparison(
             other,
             primitives.SubtractNumeric,
             primitives.SubtractNumericScalar,
@@ -353,7 +354,7 @@ class FeatureBase(object):
 
     def __div__(self, other):
         """Divide by other"""
-        return self._handle_binary_comparision(
+        return self._handle_binary_comparison(
             other,
             primitives.DivideNumeric,
             primitives.DivideNumericScalar,
@@ -394,7 +395,7 @@ class FeatureBase(object):
                     [self, other],
                     primitive=primitives.MultiplyNumericBoolean,
                 )
-        return self._handle_binary_comparision(
+        return self._handle_binary_comparison(
             other,
             primitives.MultiplyNumeric,
             primitives.MultiplyNumericScalar,
@@ -405,7 +406,7 @@ class FeatureBase(object):
 
     def __mod__(self, other):
         """Take modulus of other"""
-        return self._handle_binary_comparision(
+        return self._handle_binary_comparison(
             other,
             primitives.ModuloNumeric,
             primitives.ModuloNumericScalar,
