@@ -9,6 +9,9 @@ from featuretools.primitives.standard.transform.numeric.percentile import Percen
 from featuretools.primitives.standard.transform.numeric.rate_of_change import (
     RateOfChange,
 )
+from featuretools.primitives.standard.transform.numeric.same_as_previous import (
+    SameAsPrevious,
+)
 from featuretools.primitives.standard.transform.numeric.sine import Sine
 from featuretools.primitives.standard.transform.numeric.square_root import SquareRoot
 from featuretools.primitives.standard.transform.numeric.tangent import Tangent
