@@ -3,7 +3,7 @@ import logging
 import operator
 import warnings
 from collections import defaultdict
-from typing import Any, List
+from typing import Any, DefaultDict, Dict, List
 
 from woodwork.column_schema import ColumnSchema
 from woodwork.logical_types import Boolean, BooleanNullable
@@ -14,6 +14,7 @@ from featuretools.entityset.relationship import RelationshipPath
 from featuretools.feature_base import (
     AggregationFeature,
     DirectFeature,
+    FeatureBase,
     GroupByTransformFeature,
     IdentityFeature,
     TransformFeature,
@@ -192,21 +193,7 @@ class DeepFeatureSynthesis(object):
             ), "Can't ignore target_dataframe!"
             self.ignore_dataframes = set(ignore_dataframes)
 
-        self.ignore_columns = defaultdict(set)
-        if ignore_columns is not None:
-            # check if ignore_columns is not {str: list}
-            if not all(isinstance(i, str) for i in ignore_columns.keys()) or not all(
-                isinstance(i, list) for i in ignore_columns.values()
-            ):
-                raise TypeError("ignore_columns should be dict[str -> list]")
-            # check if list values are all of type str
-            elif not all(
-                all(isinstance(v, str) for v in value)
-                for value in ignore_columns.values()
-            ):
-                raise TypeError("list values should be of type str")
-            for df_name, cols in ignore_columns.items():
-                self.ignore_columns[df_name] = set(cols)
+        self.ignore_columns = _build_ignore_columns(ignore_columns)
         self.target_dataframe_name = target_dataframe_name
         self.es = entityset
 
@@ -751,32 +738,49 @@ class DeepFeatureSynthesis(object):
                 current_options,
             )
 
-            # If require_direct_input, require a DirectFeature in input or as a
-            # groupby, and don't create features of inputs/groupbys which are
-            # all direct features with the same relationship path
             for matching_input in matching_inputs:
                 if not can_stack_primitive_on_inputs(groupby_prim, matching_input):
                     continue
-                if not any(
-                    True for bf in matching_input if bf.number_output_features != 1
-                ):
-                    for groupby in groupby_matches:
-                        input_features = matching_input + (groupby,)
-                        if require_direct_input and (
-                            _all_direct_and_same_path(input_features)
-                            or not any(
-                                True
-                                for feature in (input_features)
-                                if isinstance(feature, DirectFeature)
-                            )
-                        ):
-                            continue
-                        new_f = GroupByTransformFeature(
-                            list(matching_input),
-                            groupby=groupby[0],
-                            primitive=groupby_prim,
+                if any(True for bf in matching_input if bf.number_output_features != 1):
+                    continue
+                if require_direct_input:
+                    if any_direct_in_matching_input := any(
+                        isinstance(bf, DirectFeature) for bf in matching_input
+                    ):
+                        all_direct_and_same_path_in_matching_input = (
+                            _all_direct_and_same_path(matching_input)
                         )
-                        features_to_add.append(new_f)
+                for groupby in groupby_matches:
+                    if require_direct_input:
+                        # If require_direct_input, require a DirectFeature in input or as a
+                        # groupby, and don't create features of inputs/groupbys which are
+                        # all direct features with the same relationship path
+                        #
+                        # If we require_direct_input, we skip Feature generation
+                        # in the following two cases:
+                        # (1) --> There are no DirectFeatures in the matching input,
+                        #         and groupby is not a DirectFeature
+                        # (2) --> All of the matching input and groupby are DirectFeatures
+                        #         with the same relationship path
+                        groupby_is_direct = isinstance(groupby[0], DirectFeature)
+                        # Checks case (1)
+                        if not any_direct_in_matching_input:
+                            if not groupby_is_direct:
+                                continue
+                        elif all_direct_and_same_path_in_matching_input:
+                            # Checks case (2)
+                            if (
+                                groupby_is_direct
+                                and groupby[0].relationship_path
+                                == matching_input[0].relationship_path
+                            ):
+                                continue
+                    new_f = GroupByTransformFeature(
+                        list(matching_input),
+                        groupby=groupby[0],
+                        primitive=groupby_prim,
+                    )
+                    features_to_add.append(new_f)
         for new_f in features_to_add:
             self._handle_new_feature(all_features=all_features, new_feature=new_f)
 
@@ -1260,22 +1264,33 @@ def check_primitive(
     return primitive
 
 
-def _all_direct_and_same_path(input_features):
-    return all(
-        isinstance(f, DirectFeature) for f in input_features
-    ) and _features_have_same_path(input_features)
-
-
-def _features_have_same_path(input_features):
+def _all_direct_and_same_path(input_features: List[FeatureBase]) -> bool:
+    """Given a list of features, returns True if they are all
+    DirectFeatures with the same relationship_path, and False if not
+    """
     path = input_features[0].relationship_path
-
-    for f in input_features[1:]:
-        if f.relationship_path != path:
+    for f in input_features:
+        if not isinstance(f, DirectFeature) or f.relationship_path != path:
             return False
-
     return True
 
 
+def _build_ignore_columns(input_dict: Dict[str, List[str]]) -> DefaultDict[str, set]:
+    """Iterates over the input dictionary to build the ignore_columns defaultdict.
+    Expects the input_dict's keys to be strings, and values to be lists of strings.
+    Throws a TypeError if they are not.
+    """
+    ignore_columns = defaultdict(set)
+    if input_dict is not None:
+        for df_name, cols in input_dict.items():
+            if not isinstance(df_name, str) or not isinstance(cols, list):
+                raise TypeError("ignore_columns should be dict[str -> list]")
+            elif not all(isinstance(c, str) for c in cols):
+                raise TypeError("list in ignore_columns must only have string values")
+            ignore_columns[df_name] = set(cols)
+    return ignore_columns
+
+
 def _direct_of_dataframe(feature, parent_dataframe):
     return (
         isinstance(feature, DirectFeature)
