@@ -1,14 +1,14 @@
-import featuretools as ft
+from featuretools import IdentityFeature
 from featuretools.primitives.utils import PrimitivesDeserializer
 
 
 def test_relationship_path(es):
-    value = ft.IdentityFeature(es["log"].ww["value"])
+    value = IdentityFeature(es["log"].ww["value"])
     assert len(value.relationship_path) == 0
 
 
 def test_serialization(es):
-    value = ft.IdentityFeature(es["log"].ww["value"])
+    value = IdentityFeature(es["log"].ww["value"])
 
     dictionary = {
         "name": "value",
@@ -17,6 +17,9 @@ def test_serialization(es):
     }
 
     assert dictionary == value.get_arguments()
-    assert value == ft.IdentityFeature.from_dictionary(
-        dictionary, es, {}, PrimitivesDeserializer
+    assert value == IdentityFeature.from_dictionary(
+        dictionary,
+        es,
+        {},
+        PrimitivesDeserializer,
     )
