@@ -1,10 +1,4 @@
 # flake8: noqa
-from featuretools.utils.cli_utils import (
-    get_featuretools_root,
-    get_installed_packages,
-    get_sys_info,
-    show_info,
-)
 from featuretools.utils.entry_point import entry_point
 from featuretools.utils.gen_utils import make_tqdm_iterator
 from featuretools.utils.time_utils import (
@@ -13,3 +7,9 @@ from featuretools.utils.time_utils import (
     make_temporal_cutoffs,
 )
 from featuretools.utils.trie import Trie
+from featuretools.utils.utils_info import (
+    get_featuretools_root,
+    get_installed_packages,
+    get_sys_info,
+    show_info,
+)
