@@ -2,10 +2,8 @@ import importlib
 import logging
 import re
 import sys
-import warnings
 from enum import Enum
 
-from packaging.version import parse
 from tqdm import tqdm
 
 logger = logging.getLogger("featuretools.utils")
@@ -14,8 +12,7 @@ logger = logging.getLogger("featuretools.utils")
 def make_tqdm_iterator(**kwargs):
     options = {"file": sys.stdout, "leave": True}
     options.update(kwargs)
-    iterator = tqdm(**options)
-    return iterator
+    return tqdm(**options)
 
 
 def get_relationship_column_id(path):
@@ -41,39 +38,6 @@ def find_descendents(cls):
             yield c
 
 
-def check_schema_version(cls, cls_type):
-    if isinstance(cls_type, str):
-        if cls_type == "entityset":
-            from featuretools.entityset.serialize import SCHEMA_VERSION
-
-            version_string = cls.get("schema_version")
-        elif cls_type == "features":
-            from featuretools.feature_base.features_serializer import SCHEMA_VERSION
-
-            version_string = cls.features_dict["schema_version"]
-
-        current = SCHEMA_VERSION
-        saved = version_string
-
-        warning_text_upgrade = (
-            "The schema version of the saved %s"
-            "(%s) is greater than the latest supported (%s). "
-            "You may need to upgrade featuretools. Attempting to load %s ..."
-            % (cls_type, version_string, SCHEMA_VERSION, cls_type)
-        )
-        if parse(current) < parse(saved):
-            warnings.warn(warning_text_upgrade)
-
-        warning_text_outdated = (
-            "The schema version of the saved %s"
-            "(%s) is no longer supported by this version "
-            "of featuretools. Attempting to load %s ..."
-            % (cls_type, version_string, cls_type)
-        )
-        if parse(current) > parse(saved):
-            logger.warning(warning_text_outdated)
-
-
 def import_or_raise(library, error_msg):
     """
     Attempts to import the requested library.  If the import fails, raises an
